@@ -7,8 +7,8 @@ import pytest
 @pytest.fixture
 def config_file_path(tmpdir):
     """Returns a string path to a sectionless config"""
-    cfg_file = tmpdir.join('conf.ini')
-    with open(str(cfg_file), 'w') as fdesc:
+    cfg_file = tmpdir.join("conf.ini")
+    with open(str(cfg_file), "w") as fdesc:
         fdesc.write(
             dedent(
                 """
